==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/experience/actions/updateExperience.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/experience/actions/updateExperience", ['module', 'exports', 'require', './types'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = updateExperience;

    var _types = require("./types");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function updateExperience(_ref) {
      var name = _ref.name,
          segmentsEntryId = _ref.segmentsEntryId,
          segmentsExperienceId = _ref.segmentsExperienceId;
      return {
        payload: {
          name: name,
          segmentsEntryId: segmentsEntryId,
          segmentsExperienceId: segmentsExperienceId
        },
        type: _types.UPDATE_SEGMENTS_EXPERIENCE
      };
    }
    //# sourceMappingURL=updateExperience.js.map
  }
});
//# sourceMappingURL=updateExperience.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/experience/actions/updateExperience.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/experience/actions/updateExperience", ['module', 'exports', 'require', '../actions'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = updateExperience;

    var _actions = require("../actions");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function updateExperience(_ref) {
      var name = _ref.name,
          segmentsEntryId = _ref.segmentsEntryId,
          segmentsExperienceId = _ref.segmentsExperienceId;
      return {
        payload: {
          name: name,
          segmentsEntryId: segmentsEntryId,
          segmentsExperienceId: segmentsExperienceId
        },
        type: _actions.UPDATE_SEGMENTS_EXPERIENCE
      };
    }
    //# sourceMappingURL=updateExperience.js.map
  }
});
//# sourceMappingURL=updateExperience.js.map
